@@ -13,5 +13,5 @@ public = Path.cwd().joinpath("./tests/data/test_config_public.toml")
 test_config_public = toml.load(public)
 
 logging.info(
-    f"Running tests with this test_config: {test_config} and test_config_public: {test_config_public}"
+    f"Running tests with this test_config: {test_config_public} and test_config_public: {test_config_public}"
 )
